# Generated by Django 2.2.28 on 2024-03-23 19:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('whisperer', '0007_event_queue'),
    ]

    operations = [
        migrations.AddField(
            model_name='eventqueue',
            name='object_id',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='webhookevent',
            name='object_pk',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
